@@ -38,9 +38,15 @@
 #include <unistd.h>
 #endif
 
+#ifndef OS_VERSION_TEST_FILE
+#define OS_VERSION_FILE "/etc/os-version"
+#else
+#define OS_VERSION_FILE OS_VERSION_TEST_FILE
+#endif
+
 DCORE_BEGIN_NAMESPACE
 
-class DSysInfoPrivate
+class Q_DECL_HIDDEN DSysInfoPrivate
 {
 public:
     DSysInfoPrivate();
@@ -48,6 +54,8 @@ public:
 #ifdef Q_OS_LINUX
     void ensureDeepinInfo();
     bool ensureOsVersion();
+    void ensureDistributionInfo();
+    bool splitA_BC_DMode();
 #endif
     void ensureReleaseInfo();
     void ensureComputerInfo();
@@ -63,9 +71,26 @@ public:
     QString majorVersion;
     QString minorVersion;
     struct MinVersion {
-        MinVersion():A(0), BC(0), D(0){
+        enum Type {
+            A_BC_D, // 专业版
+            X_Y_Z, // 家庭版
+            A_B_C // 社区版
+        };
+        MinVersion()
+            : A(0)
+            , B(0)
+            , BC(0)
+            , C(0)
+            , D(0)
+            , X(0)
+            , Y(0)
+            , Z(0)
+        {
         }
-        uint A, BC, D; // A-BC-D
+
+        uint A, B, BC, C, D; // A-BC-D
+        uint X, Y, Z;
+        Type type;
     };
     struct OSBuild {
         OSBuild():A(0), B(0), C(0), D(0), xyz(100){
@@ -97,6 +122,41 @@ DSysInfoPrivate::DSysInfoPrivate()
 }
 
 #ifdef Q_OS_LINUX
+void DSysInfoPrivate::ensureDistributionInfo()
+{
+    if (distributionInfo)
+        return;
+
+    const QString distributionInfoFile(DSysInfo::distributionInfoPath());
+    // Generic DDE distribution info
+    distributionInfo.reset(new DDesktopEntry(distributionInfoFile));
+}
+
+bool DSysInfoPrivate::splitA_BC_DMode()
+{
+    // A-BC-D
+    bool ok = false;
+    uint minv = minorVersion.toUInt(&ok);
+    if (ok) {
+        minVersion.D = minv % 10;
+    } else if (minorVersion.length() > 0) {
+        const QString D = minorVersion.right(1);
+        if (D.contains(QRegExp("[0-9A-Z]"))) {
+            // 0-9...A-Z
+            minVersion.D = 10 + static_cast<uint>(D.data()->toLatin1() - 'A');
+        } else {
+            qWarning() << "invalid minorVersion";
+            minVersion.D = 0;
+        }
+    }
+    uint minVer = minorVersion.left(3).toUInt();
+    minVersion.BC = minVer % 100;
+    minVer /= 100;
+    minVersion.A = minVer % 10;
+    minVersion.type = MinVersion::A_BC_D;
+    return ok;
+}
+
 void DSysInfoPrivate::ensureDeepinInfo()
 {
     if (static_cast<int>(deepinType) >= 0)
@@ -168,37 +228,19 @@ void DSysInfoPrivate::ensureDeepinInfo()
     } else {
         deepinType = DSysInfo::UnknownDeepin;
     }
-
-    const QString distributionInfoFile(DSysInfo::distributionInfoPath());
-    // Generic DDE distribution info
-    distributionInfo.reset(new DDesktopEntry(distributionInfoFile));
-    QSettings distributionInfo(distributionInfoFile, QSettings::IniFormat); // TODO: treat as `.desktop` format instead of `.ini`
 }
 
 bool DSysInfoPrivate::ensureOsVersion()
 {
-    if (minVersion.A > 0)
+#ifndef OS_VERSION_TEST_FILE // 测试时总是重新读取文件
+    if (osBuild.A > 0)
         return true;
+#endif
 
-    DDesktopEntry entry("/etc/os-version");
-    majorVersion = entry.stringValue("MajorVersion", "Version");
-    minorVersion = entry.stringValue("MinorVersion", "Version");
-    Q_ASSERT(minorVersion.length() == 4);
-
-    // A-BC-D
+    DDesktopEntry entry(OS_VERSION_FILE);
     bool ok = false;
-    uint minv = minorVersion.toUInt(&ok);
-    if (ok) {
-        minVersion.D = minv % 10;
-    } else if (minorVersion.length() > 0) {
-        // 0-9...A-Z
-        minVersion.D = 10 + static_cast<uint>(minorVersion.right(1).data()->toLatin1() - 'A');
-    }
-    uint minVer = minorVersion.left(3).toUInt();
-    minVersion.BC = minVer % 100;
-    minVer /= 100;
-    minVersion.A = minVer % 10;
 
+    // 先获取版本信息
     // ABCDE.xyz
     QString osb = entry.stringValue("OsBuild", "Version");
     QStringList osbs = osb.split(".");
@@ -220,6 +262,71 @@ bool DSysInfoPrivate::ensureOsVersion()
     // xyz
     osBuild.xyz = osbs.value(1).trimmed().toUInt(&ok);
 
+    majorVersion = entry.stringValue("MajorVersion", "Version");
+    minorVersion = entry.stringValue("MinorVersion", "Version");
+
+    switch (osBuild.D) {
+    case 7: {
+        // 家庭版使用“完整版本号编码-X.Y.Z”的形式
+        const QStringList &versionList = minorVersion.split('.');
+        if (versionList.isEmpty()) {
+            // 如果读取失败直接返回为空
+            qWarning() << "no minorVersion";
+            return false;
+        } else if (versionList.length() == 2) {
+            // Z为0
+            minVersion.X = versionList.first().toUInt();
+            minVersion.Y = versionList.last().toUInt();
+            minVersion.Z = 0;
+        } else if (versionList.length() == 3) {
+            // X.Y.Z都存在
+            minVersion.X = versionList.at(0).toUInt();
+            minVersion.Y = versionList.at(1).toUInt();
+            minVersion.Z = versionList.at(2).toUInt();
+        }
+        minVersion.type = MinVersion::X_Y_Z;
+    } break;
+
+    case 3: {
+        // 社区版使用“完整版本号编码-A.B.C”的形式
+        bool a_bc_dMode = false;
+        const QStringList &versionList = minorVersion.split('.');
+        if (versionList.isEmpty()) {
+            // 如果读取失败直接返回为空
+            qWarning() << "no minorVersion";
+            return false;
+        } else if (versionList.length() == 1) {
+            QString modeVersion = versionList.first();
+            if (modeVersion.length() == 2) {
+                //A.B.C模式且B C 为0
+                minVersion.A = modeVersion.toUInt();
+                minVersion.B = 0;
+                minVersion.C = 0;
+            } else {
+                // A_BC_D模式
+                splitA_BC_DMode();
+                a_bc_dMode = true;
+            }
+        } else if (versionList.length() == 2) {
+            // C为0
+            minVersion.A = versionList.first().toUInt();
+            minVersion.B = versionList.last().toUInt();
+            minVersion.C = 0;
+        } else if (versionList.length() == 3) {
+            // A.B.C都存在
+            minVersion.A = versionList.at(0).toUInt();
+            minVersion.B = versionList.at(1).toUInt();
+            minVersion.C = versionList.at(2).toUInt();
+        }
+
+        if (!a_bc_dMode)
+            minVersion.type = MinVersion::A_B_C;
+    } break;
+    default: {
+        // A-BC-D
+        ok = splitA_BC_DMode();
+    } break;
+    }
     return ok;
 }
 
@@ -369,93 +476,8 @@ void DSysInfoPrivate::ensureReleaseInfo()
 
 void DSysInfoPrivate::ensureComputerInfo()
 {
-    if (memoryAvailableSize >= 0)
-        return;
-
 #ifdef Q_OS_LINUX
-    struct utsname u;
-    if (uname(&u) == 0)
-        computerName = QString::fromLatin1(u.nodename);
 
-    QFile file("/proc/cpuinfo");
-
-    if (file.open(QFile::ReadOnly)) {
-        QMap<QString, QString> map = parseInfoFile(file);
-        if (map.contains("Processor")) {
-            // arm-cpuinfo hw_kirin-cpuinfo
-            cpuModelName = map.value("Processor");
-        } else if (map.contains("model name")) {
-            // cpuinfo
-            cpuModelName = map.value("model name");
-        } else if (map.contains("cpu model")) {
-            // loonson3-cpuinfo sw-cpuinfo
-            cpuModelName = map.value("cpu model");
-        }
-
-        file.close();
-    }
-
-    memoryAvailableSize = get_phys_pages() * sysconf(_SC_PAGESIZE);
-
-    // Getting Memory Installed Size
-    // TODO: way to not dept on lshw?
-    if (!QStandardPaths::findExecutable("lshw").isEmpty()) {
-        QProcess lshw;
-
-        lshw.start("lshw", {"-c", "memory", "-json", "-sanitize"}, QIODevice::ReadOnly);
-
-        if (!lshw.waitForFinished()) {
-            return;
-        }
-
-        const QByteArray &lshwInfoJson = lshw.readAllStandardOutput();
-        QJsonArray lshwResultArray = QJsonDocument::fromJson(lshwInfoJson).array();
-        if (!lshwResultArray.isEmpty()) {
-            QJsonValue memoryHwInfo = lshwResultArray.first();
-            QString id = memoryHwInfo.toObject().value("id").toString();
-            Q_ASSERT(id == "memory");
-            memoryInstalledSize = memoryHwInfo.toObject().value("size").toDouble(); // TODO: check "units" is "bytes" ?
-        }
-    }
-
-    // Getting Disk Size
-    const QString &deviceName = QStorageInfo::root().device();
-    QProcess lsblk;
-
-    lsblk.start("lsblk", {"-Jlpb", "-oNAME,KNAME,PKNAME,SIZE"}, QIODevice::ReadOnly);
-
-    if (!lsblk.waitForFinished()) {
-        return;
-    }
-
-    const QByteArray &diskStatusJson = lsblk.readAllStandardOutput();
-    QJsonDocument diskStatus = QJsonDocument::fromJson(diskStatusJson);
-    QJsonValue diskStatusJsonValue = diskStatus.object().value("blockdevices");
-    QMap<QString, QPair<QString, qulonglong>> deviceParentAndSizeMap;
-
-    if (!diskStatusJsonValue.isUndefined()) {
-        QJsonArray diskStatusArray = diskStatusJsonValue.toArray();
-        QString keyName;
-
-        for (const QJsonValue oneValue : diskStatusArray) {
-            QString name = oneValue.toObject().value("name").toString();
-            QString kname = oneValue.toObject().value("kname").toString();
-            QString pkname = oneValue.toObject().value("pkname").toString();
-            qulonglong size = oneValue.toObject().value("size").toVariant().toULongLong();
-
-            if (keyName.isNull() && deviceName == name) {
-                keyName = kname;
-            }
-
-            deviceParentAndSizeMap[kname] = QPair<QString, qulonglong>(pkname, size);
-        }
-
-        while (!deviceParentAndSizeMap[keyName].first.isNull()) {
-            keyName = deviceParentAndSizeMap[keyName].first;
-        }
-
-        diskSize = deviceParentAndSizeMap[keyName].second;
-    }
 #endif
 }
 
@@ -488,8 +510,8 @@ QString DSysInfo::operatingSystemName()
 
 #ifdef Q_OS_LINUX
 /*!
- * \brief Check current distro is Deepin or not.
- * \note Uos will also return true.
+  \brief Check current distro is Deepin or not.
+  \note Uos will also return true.
  */
 bool DSysInfo::isDeepin()
 {
@@ -541,9 +563,9 @@ QString DSysInfo::deepinCopyright()
 }
 
 /*!
- * \~chinese \brief DSysInfo::osType 系统类型
- * \~chinese \row 显示系统类型【1：桌面】【2：服务器】【3：专用设备】
- * \~chinese \note 根据 osBuild.B 判断
+  \brief DSysInfo::osType 系统类型
+  显示系统类型【1：桌面】【2：服务器】【3：专用设备】
+  \note 根据 osBuild.B 判断
  */
 DSysInfo::UosType DSysInfo::uosType()
 {
@@ -558,29 +580,58 @@ DSysInfo::UosType DSysInfo::uosType()
 }
 
 /*!
- * \~chinese \brief DSysInfo::osEditionType 版本类型
- * \~chinese \row 显示版本类型 专业版/个人版/社区版...
- * \~chinese \note 根据 osBuild.B && osBuild.D
+  \brief DSysInfo::osEditionType 版本类型
+  显示版本类型 专业版/个人版/社区版...
+  \note 根据 osBuild.B && osBuild.D
  */
 DSysInfo::UosEdition DSysInfo::uosEditionType()
 {
     siGlobal->ensureOsVersion();
     UosEdition ospt = UosEditionUnknown;
-
     if (siGlobal->osBuild.B == UosDesktop) {
-        ospt = static_cast<UosEdition>(siGlobal->osBuild.D);
+        switch (siGlobal->osBuild.D) {
+        case 1:
+            return UosProfessional;
+        case 2:
+        case 7:
+            // 新版本家庭版(7)与旧版本个人版(2)同为Home 不修改旧有逻辑的情况下新增7保证对旧版的适配
+            return UosHome;
+        case 3:
+            return UosCommunity;
+        case 4:
+            return UosMilitary;
+        case 5:
+            return UosDeviceEdition;
+        case 6:
+            return UosEducation;
+        default:
+            break;
+        }
     } else if (siGlobal->osBuild.B == UosServer) {
-        ospt = static_cast<UosEdition>(siGlobal->osBuild.D + UosMilitary);
+        switch (siGlobal->osBuild.D) {
+        case 1:
+            return UosEnterprise;
+        case 2:
+            return UosEnterpriseC;
+        case 3:
+            return UosEuler;
+        case 4:
+            return UosMilitaryS;
+        case 5:
+            return UosDeviceEdition;
+        default:
+            break;
+        }
     } else if (siGlobal->osBuild.B == UosDevice){
-        ospt = UosProfessional;
+        ospt = UosEnterprise; // os-version 1.4 if B==Device then et=Enterprise
     }
 
     return ospt;
 }
 
 /*!
- * \~chinese \brief DSysInfo::osArch 架构信息（使用一个字节的二进制位，从低位到高位）
- * \~chinese \row 【0x8 sw64】【0x4 mips64】【0x2 arm64】【0x1 amd64】
+  \brief DSysInfo::osArch 架构信息（使用一个字节的二进制位，从低位到高位）
+  【0x8 sw64】【0x4 mips64】【0x2 arm64】【0x1 amd64】
  */
 DSysInfo::UosArch DSysInfo::uosArch()
 {
@@ -591,16 +642,16 @@ DSysInfo::UosArch DSysInfo::uosArch()
 
 static QString getUosVersionValue(const QString &key, const QLocale &locale)
 {
-    DDesktopEntry entry("/etc/os-version");
+    DDesktopEntry entry(OS_VERSION_FILE);
     QString localKey = QString("%1[%2]").arg(key, locale.name());
 
     return entry.stringValue(localKey, "Version", entry.stringValue(key, "Version"));
 }
 
 /*!
- * \~chinese \brief DSysInfo::osProductTypeName 版本名称
- * \~chinese \row ProductType[xx] 项对应的值, 如果找不到对应语言的默认使用 ProductType的值(Desktop/Server/Device)
- * \~chinese \param locale 当前系统语言
+  \brief DSysInfo::osProductTypeName 版本名称
+  ProductType[xx] 项对应的值, 如果找不到对应语言的默认使用 ProductType的值(Desktop/Server/Device)
+  \a locale 当前系统语言
  */
 QString DSysInfo::uosProductTypeName(const QLocale &locale)
 {
@@ -608,9 +659,10 @@ QString DSysInfo::uosProductTypeName(const QLocale &locale)
 }
 
 /*!
- * \~chinese \brief DSysInfo::osSystemName 版本名称
- * \~chinese \row SystemName[xx] 项对应的值, 如果找不到对应语言的默认使用 SystemName 的值 Uniontech OS
- * \~chinese \param locale 当前系统语言
+  \brief DSysInfo::osSystemName 版本名称
+  
+  SystemName[xx] 项对应的值, 如果找不到对应语言的默认使用 SystemName 的值 Uniontech OS
+  \a locale 当前系统语言
  */
 QString DSysInfo::uosSystemName(const QLocale &locale)
 {
@@ -618,9 +670,9 @@ QString DSysInfo::uosSystemName(const QLocale &locale)
 }
 
 /*!
- * \~chinese \brief DSysInfo::osEditionName 版本名称
- * \~chinese \row EditionName[xx] 项对应的值, 如果找不到对应语言的默认使用 EditionName 的值(Professional/Home/Community...)
- * \~chinese \param locale 当前系统语言
+  \brief DSysInfo::osEditionName 版本名称
+   EditionName[xx] 项对应的值, 如果找不到对应语言的默认使用 EditionName 的值(Professional/Home/Community...)
+  \a locale 当前系统语言
  */
 QString DSysInfo::uosEditionName(const QLocale &locale)
 {
@@ -628,44 +680,86 @@ QString DSysInfo::uosEditionName(const QLocale &locale)
 }
 
 /*!
- * \~chinese \brief DSysInfo::spVersion 阶段版本名称
- * \~chinese \row 小版本号 A-BC-D 中 BC, 返回 SP1-SPxx， 如果正式版返回空
- * \~chinese \note minVersion.BC == 00：正式版本    minVersion.BC == 01-99：SP1….SP99
+  \brief DSysInfo::spVersion 阶段版本名称
+  小版本号 A-BC-D 中 BC、 A.B.C 中的 B
+  返回 SP1-SPxx， 如果正式版返回空
+  X.Y.Z模式下暂不支持返回此版本号
+  \note minVersion.BC == 00：正式版本    minVersion.BC | minVersion.B == 01-99：SP1….SP99
  */
 QString DSysInfo::spVersion()
 {
     siGlobal->ensureOsVersion();
-    if (siGlobal->minVersion.BC > 0) {
-        return QString("SP%1").arg(siGlobal->minVersion.BC);
-    } else {
-        return QString(); // 00 正式版
+    switch (siGlobal->minVersion.type) {
+    case DSysInfoPrivate::MinVersion::A_BC_D: {
+        if (siGlobal->minVersion.BC > 0) {
+            return QString("SP%1").arg(siGlobal->minVersion.BC);
+        } else {
+            return QString(); // 00 正式版
+        }
     }
+
+    case DSysInfoPrivate::MinVersion::A_B_C: {
+        if (siGlobal->minVersion.B > 0) {
+            return QStringLiteral("SP%1").arg(siGlobal->minVersion.B);
+        } else {
+            return {};
+        }
+    }
+
+    case DSysInfoPrivate::MinVersion::X_Y_Z:
+        qWarning() << "Getting the SP version in this mode is not supported.";
+        return {};
+    }
+    return QString();
 }
 
 /*!
- * \~chinese \brief DSysInfo::udpateVersion 更新版本名称
- * \~chinese \row 小版本号 A-BC-D 中 D, 返回 update1… update9， 如果正式版返回空
- * \~chinese \note minVersion.D == 0：正式版本    minVersion.D == 1-9：update1… update9,updateA...updateZ
+  \brief DSysInfo::udpateVersion 更新版本名称
+  小版本号 A-BC-D 中 D、A.B.C 模式中的 C
+  返回 update1… update9， 如果正式版返回空
+  X.Y.Z模式下暂不支持返回此版本号
+  \note minVersion.D == 0：正式版本    minVersion.D | minVersion.C == 1-9：update1… update9,updateA...updateZ
  */
 QString DSysInfo::udpateVersion()
 {
     siGlobal->ensureOsVersion();
-    if (siGlobal->minVersion.D > 0) {
-        uint uv = siGlobal->minVersion.D;
-        if (uv < 10) {
-            return QString("update%1").arg(uv);
+    switch (siGlobal->minVersion.type) {
+    case DSysInfoPrivate::MinVersion::A_BC_D: {
+        if (siGlobal->minVersion.D > 0) {
+            uint uv = siGlobal->minVersion.D;
+            if (uv < 10) {
+                return QString("update%1").arg(uv);
+            } else if (uv < 36) {
+                return QString("update").append(QChar(uv - 10 + 'A'));
+            } else {
+                qWarning() << "invalid update versoin";
+                break;
+            }
         } else {
-            return QString("update").append(QChar(uv - 10 + 'A'));
+            break; // 0 正式版
         }
-    } else {
-        return QString(); // 0 正式版
     }
+
+    case DSysInfoPrivate::MinVersion::A_B_C: {
+        if (siGlobal->minVersion.C > 0) {
+            return QStringLiteral("update%1").arg(siGlobal->minVersion.C);
+        } else {
+            break;
+        }
+    }
+
+    case DSysInfoPrivate::MinVersion::X_Y_Z:
+        qWarning() << "Getting the update version in this mode is not supported.";
+        break;
+    }
+
+    return {};
 }
 
 /*!
- * \~chinese \brief DSysInfo::majorVersion 主版本号
- * \~chinese \row 主版本号 【20】【23】【25】【26】【29】【30】
- * \~chinese \note 返回 MajorVersion 的值
+  \brief DSysInfo::majorVersion 主版本号
+  主版本号 【20】【23】【25】【26】【29】【30】
+  \note 返回 MajorVersion 的值
  */
 QString DSysInfo::majorVersion()
 {
@@ -674,9 +768,10 @@ QString DSysInfo::majorVersion()
 }
 
 /*!
- * \~chinese \brief DSysInfo::minorVersion 小版本号
- * \~chinese \row 【ABCD】 ·[0-9]{4}
- * \~chinese \note 返回 MinorVersion 的值
+  \brief DSysInfo::minorVersion 小版本号
+ *【ABCD】 ·[0-9]{4}
+ *【A.B.C】 或者【X.Y.Z】
+  \note 返回 MinorVersion 的值
  */
 QString DSysInfo::minorVersion()
 {
@@ -685,9 +780,9 @@ QString DSysInfo::minorVersion()
 }
 
 /*!
- * \~chinese \brief DSysInfo::buildVersion 小版本号
- * \~chinese \row 系统镜像批次号，按时间顺序（不可回退）从100-999递增
- * \~chinese \note 返回 osBuild.xyz 的值
+  \brief DSysInfo::buildVersion 小版本号
+  系统镜像批次号，按时间顺序（不可回退）从100-999递增
+  \note 返回 osBuild.xyz 的值
  */
 QString DSysInfo::buildVersion()
 {
@@ -725,16 +820,16 @@ QString DSysInfo::distributionInfoSectionName(DSysInfo::OrgType type)
 }
 
 /*!
- * \return the organization name.
- *
- * use \l type as Distribution to get the name of current deepin distribution itself.
- *
- * \sa deepinDistributionInfoPath()
+  \return the organization name.
+  
+  use \a type as Distribution to get the name of current deepin distribution itself.
+  
+  \sa deepinDistributionInfoPath()
  */
 QString DSysInfo::distributionOrgName(DSysInfo::OrgType type, const QLocale &locale)
 {
 #ifdef Q_OS_LINUX
-    siGlobal->ensureDeepinInfo();
+    siGlobal->ensureDistributionInfo();
 #endif
 
     QString fallback = type == Distribution ? QStringLiteral("Deepin") : QString();
@@ -748,16 +843,16 @@ QString DSysInfo::deepinDistributorName()
 }
 
 /*!
- * \return the organization website name and url.
- *
- * use \l type as Distribution to get the name of current deepin distribution itself.
- *
- * \sa deepinDistributionInfoPath()
+  \return the organization website name and url.
+  
+  use \a type as Distribution to get the name of current deepin distribution itself.
+  
+  \sa deepinDistributionInfoPath()
  */
 QPair<QString, QString> DSysInfo::distributionOrgWebsite(DSysInfo::OrgType type)
 {
 #ifdef Q_OS_LINUX
-    siGlobal->ensureDeepinInfo();
+    siGlobal->ensureDistributionInfo();
 #endif
 
     QString fallbackSiteName = type == Distribution ? QStringLiteral("www.deepin.org") : QString();
@@ -775,11 +870,11 @@ QPair<QString, QString> DSysInfo::deepinDistributorWebsite()
 }
 
 /*!
- * \return the obtained organization logo path, or the given \l fallback one if there are no such logo.
- *
- * use \l type as Distribution to get the logo of current deepin distribution itself.
- *
- * \sa deepinDistributionInfoPath()
+  \return the obtained organization logo path, or the given \a fallback one if there are no such logo.
+  
+  use \a type as Distribution to get the logo of current deepin distribution itself.
+  
+  \sa deepinDistributionInfoPath()
  */
 QString DSysInfo::distributionOrgLogo(DSysInfo::OrgType orgType, DSysInfo::LogoType type, const QString &fallback)
 {
@@ -827,16 +922,16 @@ QString DSysInfo::productVersion()
 }
 
 /*!
- * \brief Check if current edition is a community edition
- *
- * Developer can use this way to check if we need enable or disable features
- * for community or enterprise edition.
- *
- * Current rule:
- *  - Professional, Server, Personal edition (DeepinType) will be treat as Enterprise edition.
- *  - Uos (ProductType) will be treat as Enterprise edition.
- *
- * \return true if it's on a community edition distro/installation
+  \brief Check if current edition is a community edition
+  
+  Developer can use this way to check if we need enable or disable features
+  for community or enterprise edition.
+  
+  Current rule:
+   - Professional, Server, Personal edition (DeepinType) will be treat as Enterprise edition.
+   - Uos (ProductType) will be treat as Enterprise edition.
+  
+  \return true if it's on a community edition distro/installation
  */
 bool DSysInfo::isCommunityEdition()
 {
@@ -860,43 +955,132 @@ bool DSysInfo::isCommunityEdition()
 
 QString DSysInfo::computerName()
 {
-    siGlobal->ensureComputerInfo();
+#ifdef Q_OS_LINUX
+    struct utsname u;
+    if (uname(&u) == 0)
+        siGlobal->computerName = QString::fromLatin1(u.nodename);
 
     return siGlobal->computerName;
+#endif
+    return QString();
 }
 
 QString DSysInfo::cpuModelName()
 {
-    siGlobal->ensureComputerInfo();
+#ifdef Q_OS_LINUX
+    static QFile file("/proc/cpuinfo");
 
+    if (file.open(QFile::ReadOnly)) {
+        QMap<QString, QString> map = siGlobal->parseInfoFile(file);
+        if (map.contains("Processor")) {
+            // arm-cpuinfo hw_kirin-cpuinfo
+            siGlobal->cpuModelName = map.value("Processor");
+        } else if (map.contains("model name")) {
+            // cpuinfo
+            siGlobal->cpuModelName = map.value("model name");
+        } else if (map.contains("cpu model")) {
+            // loonson3-cpuinfo sw-cpuinfo
+            siGlobal->cpuModelName = map.value("cpu model");
+        }
+
+        file.close();
+    }
     return siGlobal->cpuModelName;
+#endif
+    return QString();
 }
 
 /*!
- * \return the installed memory size
+  \return the installed memory size
  */
 qint64 DSysInfo::memoryInstalledSize()
 {
-    siGlobal->ensureComputerInfo();
+#ifdef Q_OS_LINUX
+    // Getting Memory Installed Size
+    // TODO: way to not dept on lshw?
+    if (!QStandardPaths::findExecutable("lshw").isEmpty()) {
+        QProcess lshw;
+
+        lshw.start("lshw", {"-c", "memory", "-json", "-sanitize"}, QIODevice::ReadOnly);
+
+        if (!lshw.waitForFinished()) {
+            return -1;
+        }
+
+        const QByteArray &lshwInfoJson = lshw.readAllStandardOutput();
+        QJsonArray lshwResultArray = QJsonDocument::fromJson(lshwInfoJson).array();
+        if (!lshwResultArray.isEmpty()) {
+            QJsonValue memoryHwInfo = lshwResultArray.first();
+            QString id = memoryHwInfo.toObject().value("id").toString();
+            Q_ASSERT(id == "memory");
+            siGlobal->memoryInstalledSize = memoryHwInfo.toObject().value("size").toDouble(); // TODO: check "units" is "bytes" ?
+        }
+    }
 
     return siGlobal->memoryInstalledSize;
+#endif
+    return -1;
 }
 
 /*!
- * \return the total available to use memory size
+  \return the total available to use memory size
  */
 qint64 DSysInfo::memoryTotalSize()
 {
-    siGlobal->ensureComputerInfo();
-
+#ifdef Q_OS_LINUX
+    siGlobal->memoryAvailableSize = get_phys_pages() * sysconf(_SC_PAGESIZE);
     return siGlobal->memoryAvailableSize;
+#endif
+    return -1;
 }
 
 qint64 DSysInfo::systemDiskSize()
 {
-    siGlobal->ensureComputerInfo();
+#ifdef Q_OS_LINUX
+    // Getting Disk Size
+    const QString &deviceName = QStorageInfo::root().device();
+    QProcess lsblk;
+
+    lsblk.start("lsblk", {"-Jlpb", "-oNAME,KNAME,PKNAME,SIZE"}, QIODevice::ReadOnly);
+
+    if (!lsblk.waitForFinished()) {
+        return -1;
+    }
+
+    const QByteArray &diskStatusJson = lsblk.readAllStandardOutput();
+    QJsonDocument diskStatus = QJsonDocument::fromJson(diskStatusJson);
+    QJsonValue diskStatusJsonValue = diskStatus.object().value("blockdevices");
+    QMap<QString, QPair<QString, qulonglong>> deviceParentAndSizeMap;
+
+    if (!diskStatusJsonValue.isUndefined()) {
+        QJsonArray diskStatusArray = diskStatusJsonValue.toArray();
+        QString keyName;
+
+        for (const QJsonValue oneValue : diskStatusArray) {
+            QString name = oneValue.toObject().value("name").toString();
+            QString kname = oneValue.toObject().value("kname").toString();
+            QString pkname = oneValue.toObject().value("pkname").toString();
+            qulonglong size = oneValue.toObject().value("size").toVariant().toULongLong();
+
+            if (keyName.isNull() && deviceName == name) {
+                keyName = kname;
+            }
+
+            deviceParentAndSizeMap[kname] = QPair<QString, qulonglong>(pkname, size);
+        }
+
+        while (!deviceParentAndSizeMap[keyName].first.isNull()) {
+            keyName = deviceParentAndSizeMap[keyName].first;
+        }
+
+        siGlobal->diskSize = deviceParentAndSizeMap[keyName].second;
+    }
 
     return siGlobal->diskSize;
+
+#endif
+
+    return -1;
 }
 
 DCORE_END_NAMESPACE
